Installing
==========

You can install esmlab-regrid with ``pip``, ``conda``, or by installing from source.

Pip
---

Pip can be used to install esmlab-regrid::

   pip install esmlab-regrid

Conda
-----

To install the latest version of esmlab-regrid from the
`conda-forge <https://conda-forge.github.io/>`_ repository using
`conda <https://www.anaconda.com/downloads>`_::

    conda install -c conda-forge esmlab-regrid

Install from Source
-------------------

To install esmlab-regrid from source, clone the repository from `github
<https://github.com/NCAR/esmlab-regrid>`_::

    git clone https://github.com/NCAR/esmlab-regrid.git
    cd esmlab-regrid
    pip install .

You can also install directly from git master branch::

    pip install git+https://github.com/NCAR/esmlab-regrid


Test
----

Test esmlab-regrid with ``pytest``::

    git clone https://github.com/NCAR/esmlab-regrid.git
    cd esmlab-regrid
    pytest - v
